@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -76,8 +76,8 @@ void RichTextComposerImages::addImageHelper(const QUrl &url, int width, int heig
                    url.path()));
         return;
     }
-    QFileInfo fi(url.path());
-    QString imageName
+    const QFileInfo fi(url.path());
+    const QString imageName
         = fi.baseName().isEmpty()
           ? QStringLiteral("image.png")
           : QString(fi.baseName() + QLatin1String(".png"));
@@ -105,7 +105,7 @@ void RichTextComposerImages::loadImage(const QImage &image, const QString &match
                                                              QUrl(resourceName), QVariant(image));
                         QTextImageFormat format;
                         format.setName(resourceName);
-                        if ((imageFormat.width() != 0) && (imageFormat.height() != 0)) {
+                        if ((imageFormat.width() != 0.0) && (imageFormat.height() != 0.0)) {
                             format.setWidth(imageFormat.width());
                             format.setHeight(imageFormat.height());
                         }
@@ -210,15 +210,14 @@ QList<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
 
     QTextBlock currentBlock = doc->begin();
     while (currentBlock.isValid()) {
-        QTextBlock::iterator it;
-        for (it = currentBlock.begin(); !it.atEnd(); ++it) {
+        for (QTextBlock::iterator it = currentBlock.begin(); !it.atEnd(); ++it) {
             QTextFragment fragment = it.fragment();
             if (fragment.isValid()) {
                 QTextImageFormat imageFormat = fragment.charFormat().toImageFormat();
                 if (imageFormat.isValid()) {
                     //TODO: Replace with a way to see if an image is an embedded image or a remote
                     QUrl url(imageFormat.name());
-                    if (!url.isValid() || !url.scheme().startsWith(QStringLiteral("http"))) {
+                    if (!url.isValid() || !url.scheme().startsWith(QLatin1String("http"))) {
                         retList.append(imageFormat);
                     }
                 }
@@ -231,7 +230,7 @@ QList<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
 
 void RichTextComposerImages::insertImage(const QImage &image, const QFileInfo &fileInfo)
 {
-    QString imageName = fileInfo.baseName().isEmpty()
+    const QString imageName = fileInfo.baseName().isEmpty()
                         ? i18nc("Start of the filename for an image", "image")
                         : fileInfo.baseName();
     addImageHelper(imageName, image);
