@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -102,12 +102,12 @@ void RichTextExternalComposer::startExternalEditor()
         // construct command line...
         QHash<QChar, QString> map;
         map.insert(QLatin1Char('l'), QString::number(d->richTextComposer->textCursor().blockNumber() + 1));
-        map.insert(QLatin1Char('w'), QString::number((qulonglong)d->richTextComposer->winId()));
+        map.insert(QLatin1Char('w'), QString::number(static_cast<qulonglong>(d->richTextComposer->winId())));
         map.insert(QLatin1Char('f'), d->extEditorTempFile->fileName());
         const QString cmd = KMacroExpander::expandMacrosShellQuote(commandLine, map);
         const QStringList arg = KShell::splitArgs(cmd);
         bool filenameAdded = false;
-        if (commandLine.contains(QStringLiteral("%f"))) {
+        if (commandLine.contains(QLatin1String("%f"))) {
             filenameAdded = true;
         }
         QStringList command;
@@ -124,7 +124,7 @@ void RichTextExternalComposer::startExternalEditor()
             (*d->externalEditorProcess) << d->extEditorTempFile->fileName();
         }
 
-        connect(d->externalEditorProcess, QOverload<int,QProcess::ExitStatus>::of(&KProcess::finished), this, &RichTextExternalComposer::slotEditorFinished);
+        connect(d->externalEditorProcess, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &RichTextExternalComposer::slotEditorFinished);
         d->externalEditorProcess->start();
         if (!d->externalEditorProcess->waitForStarted()) {
             d->cannotStartProcess(commandLine);
