@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -144,7 +144,11 @@ void PlainTextSyntaxSpellCheckingHighlighter::highlightBlock(const QString &text
 
     const auto nextBlock = currentBlock().next();
     if (nextBlock.isValid()) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+        QMetaObject::invokeMethod(this, [this, nextBlock] { rehighlightBlock(nextBlock); }, Qt::QueuedConnection);
+#else
         QMetaObject::invokeMethod(this, "rehighlightBlock", Qt::QueuedConnection, Q_ARG(QTextBlock, nextBlock));
+#endif
     }
 }
 
